==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/GovernanceBundlesResponse.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.GovernanceBundle;
import com.okta.sdk.resource.model.GovernanceBundlesResponseLinks;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * GovernanceBundlesResponse
 */
@JsonPropertyOrder({ GovernanceBundlesResponse.JSON_PROPERTY_BUNDLES, GovernanceBundlesResponse.JSON_PROPERTY_LINKS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class GovernanceBundlesResponse implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_BUNDLES = "bundles";
    private List<GovernanceBundle> bundles = null;

    public static final String JSON_PROPERTY_LINKS = "_links";
    private GovernanceBundlesResponseLinks links;

    public GovernanceBundlesResponse() {
    }

    public GovernanceBundlesResponse bundles(List<GovernanceBundle> bundles) {

        this.bundles = bundles;
        return this;
    }

    public GovernanceBundlesResponse addbundlesItem(GovernanceBundle bundlesItem) {
        if (this.bundles == null) {
            this.bundles = new ArrayList<>();
        }
        this.bundles.add(bundlesItem);
        return this;
    }

    /**
     * Get bundles
     *
     * @return bundles
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_BUNDLES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<GovernanceBundle> getBundles() {
        return bundles;
    }

    @JsonProperty(JSON_PROPERTY_BUNDLES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setBundles(List<GovernanceBundle> bundles) {
        this.bundles = bundles;
    }

    public GovernanceBundlesResponse links(GovernanceBundlesResponseLinks links) {

        this.links = links;
        return this;
    }

    /**
     * Get links
     *
     * @return links
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public GovernanceBundlesResponseLinks getLinks() {
        return links;
    }

    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLinks(GovernanceBundlesResponseLinks links) {
        this.links = links;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        GovernanceBundlesResponse governanceBundlesResponse = (GovernanceBundlesResponse) o;
        return Objects.equals(this.bundles, governanceBundlesResponse.bundles)
                && Objects.equals(this.links, governanceBundlesResponse.links);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(bundles, links);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class GovernanceBundlesResponse {\n");
        sb.append("    bundles: ").append(toIndentedString(bundles)).append("\n");
        sb.append("    links: ").append(toIndentedString(links)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/GovernanceBundlesResponse.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.GovernanceBundle;
import com.okta.sdk.resource.model.GovernanceBundlesResponseLinks;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * GovernanceBundlesResponse
 */
@JsonPropertyOrder({ GovernanceBundlesResponse.JSON_PROPERTY_BUNDLES, GovernanceBundlesResponse.JSON_PROPERTY_LINKS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class GovernanceBundlesResponse implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_BUNDLES = "bundles";
    private List<GovernanceBundle> bundles = null;

    public static final String JSON_PROPERTY_LINKS = "_links";
    private GovernanceBundlesResponseLinks links;

    public GovernanceBundlesResponse() {
    }

    public GovernanceBundlesResponse bundles(List<GovernanceBundle> bundles) {

        this.bundles = bundles;
        return this;
    }

    public GovernanceBundlesResponse addbundlesItem(GovernanceBundle bundlesItem) {
        if (this.bundles == null) {
            this.bundles = new ArrayList<>();
        }
        this.bundles.add(bundlesItem);
        return this;
    }

    /**
     * Get bundles
     *
     * @return bundles
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_BUNDLES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<GovernanceBundle> getBundles() {
        return bundles;
    }

    @JsonProperty(JSON_PROPERTY_BUNDLES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setBundles(List<GovernanceBundle> bundles) {
        this.bundles = bundles;
    }

    public GovernanceBundlesResponse links(GovernanceBundlesResponseLinks links) {

        this.links = links;
        return this;
    }

    /**
     * Get links
     *
     * @return links
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public GovernanceBundlesResponseLinks getLinks() {
        return links;
    }

    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLinks(GovernanceBundlesResponseLinks links) {
        this.links = links;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        GovernanceBundlesResponse governanceBundlesResponse = (GovernanceBundlesResponse) o;
        return Objects.equals(this.bundles, governanceBundlesResponse.bundles)
                && Objects.equals(this.links, governanceBundlesResponse.links);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(bundles, links);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class GovernanceBundlesResponse {\n");
        sb.append("    bundles: ").append(toIndentedString(bundles)).append("\n");
        sb.append("    links: ").append(toIndentedString(links)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
